@@ -356,7 +356,7 @@ def assignment_report(assignment_name, subs_filter={}, port=8050):
                     
                 ],
                 align='center',
-                no_gutters=True
+                # no_gutters=True
             ),
             href="#"
         ),
