@@ -56,19 +56,21 @@ def cohort_report(cohort_name, time_range={}, port=8051):
         
     assignments, n_assignment = Assignment.find({'cohortId': cohort._id, 'memberOnly': 'true'})
     if n_assignment > 0:
-        survey = assignments[assignments['assignmentType']=='FEEDBACK'].iloc[0].to_dict()
-        survey = Assignment(survey)
+        if (assignments[assignments['assignmentType']=='FEEDBACK'].shape[0] > 0):
+            survey = assignments[assignments['assignmentType']=='FEEDBACK'].iloc[0].to_dict()
+            survey = Assignment(survey)
+        else:
+            survey = Assignment({'_id': '', 'questions': []})
         assignments = assignments[assignments['assignmentType']!='FEEDBACK']
         assignments = assignments.sort_values('name').reset_index()
     else:
         assignments = pd.DataFrame(columns=['_id', 'assignmentType', 'name', 'cohort', 'questions', 'totalScore'])
-        survey = Assignment({'_id': '', 'questions': []})
+        
         
     survey_questions = {}
     for q_index, q in enumerate(survey.questions):
         if len(q['choices'])>=10:
-            survey_questions[q_index] = q['question'].split('\n')[0]
-    survey_questions 
+            survey_questions[q_index] = q['question'].split('\n')[0] 
 
     filters = {'include_staffs': False}
 
@@ -128,13 +130,13 @@ def cohort_report(cohort_name, time_range={}, port=8051):
                 session_attendances = pd.DataFrame(columns=attendance_columns)
             attendances_raw = pd.concat([attendances_raw, session_attendances])
             
+        subs_columns = ['_id', 'cohortMember', 'assignment', 'name', 'email', 'currentScore', 'answers', 'createdAt']
         if survey._id:
-            subs_columns = ['_id', 'cohortMember', 'assignment', 'name', 'email', 'currentScore', 'answers', 'createdAt']
             survey_subs_raw, n_submission = Submission.find_all({'assignmentId': survey._id, **time_range})
             if n_submission > 0:
                 survey_subs_raw = survey_subs_raw[subs_columns]
             else:
-                survey_subs_raw = pd.DataFrame(subs_columns)
+                survey_subs_raw = pd.DataFrame(columns=subs_columns)
 
         # Save data in store
         store['df_student'] = df_student
@@ -159,7 +161,7 @@ def cohort_report(cohort_name, time_range={}, port=8051):
         member_ids = students['cohortMemberId'].unique()
         store['grades'] = store['grades_raw'][store['grades_raw']['cohortMember'].isin(member_ids)].copy()
         store['attendances'] = store['attendances_raw'][store['attendances_raw']['cohortMember'].isin(member_ids)].copy()
-        store['survey_subs'] = store['survey_subs_raw'][store['survey_subs_raw']['cohortMember'].isin(member_ids)].copy()
+        store['survey_subs'] = store['survey_subs_raw'][store['survey_subs_raw']['cohortMember'].isin(member_ids)].copy() if store['survey_subs_raw'].shape[0] > 0 else store['survey_subs_raw']
 
         store['students'] = students
         store['n_student'] = store['students'].shape[0]
@@ -209,23 +211,29 @@ def cohort_report(cohort_name, time_range={}, port=8051):
         })
         attendance_report['attendance_rate'] = (attendance_report['participant']*100/n_student).apply(math.ceil)
         
-        assignment_report = pd.concat(pd.DataFrame(get_assignment_report(row, store)) for index, row in assignments.iterrows())
-        assignment_report['submission_rate'] = (assignment_report['n_submitted'] * 100 / n_student).apply(math.ceil)
-        
+        if (assignments.shape[0] > 0):
+            assignment_report = pd.concat(pd.DataFrame(get_assignment_report(row, store)) for index, row in assignments.iterrows())
+            assignment_report['submission_rate'] = (assignment_report['n_submitted'] * 100 / n_student).apply(math.ceil)
+        else:
+            assignment_report = pd.DataFrame(columns=['name', 'n_submitted', 'avg_score', 'submission_rate'])
+                
         grades.rename(columns={'assignment': 'assignment_id'}, inplace=True)
         assignments['assignment_id'] = assignments['_id']
         store['grades'] = grades.merge(assignments[['assignment_id', 'name']], on='assignment_id')
         
-        survey_report = pd.concat(pd.DataFrame(get_survey_report(row)) for index, row in survey_subs.iterrows())
+        if survey_subs.shape[0] > 0:
+            survey_report = pd.concat(pd.DataFrame(get_survey_report(row)) for index, row in survey_subs.iterrows())
+        else:
+            survey_report = pd.DataFrame(columns=['name', 'email', 'createdAt', 'avg_score', *[survey_questions.values()]])
         
         store['attendance_report'] = attendance_report
         store['assignment_report'] = assignment_report
         store['survey_report'] = survey_report
-        store['submission_rate'] = math.ceil(100*assignment_report[assignment_report['n_submitted']>0]['submission_rate'].mean())/100
+        store['submission_rate'] = math.ceil(100*assignment_report[assignment_report['n_submitted']>0]['submission_rate'].mean())/100 if assignment_report[assignment_report['n_submitted']>0].shape[0]>0 else 0
         store['attendance_rate'] = math.ceil(100*attendance_report['attendance_rate'].mean())/100
         store['engagement_score'] = math.ceil(np.array([store['submission_rate'], store['attendance_rate']]).mean()*100)/100
-        store['performance_score'] = math.ceil(100*assignment_report[assignment_report['n_submitted']>0]['avg_score'].mean())/100
-        store['happiness_score'] = math.ceil(100*survey_report['avg_score'].mean())/10
+        store['performance_score'] = math.ceil(100*assignment_report[assignment_report['n_submitted']>0]['avg_score'].mean())/100 if assignment_report[assignment_report['n_submitted']>0].shape[0]>0 else 0
+        store['happiness_score'] = math.ceil(100*survey_report['avg_score'].mean())/10 if survey_report.shape[0] > 0 else 0
 
     def build_overview_scores(data):
         engagement_score = data['engagement_score']
@@ -451,20 +459,21 @@ def cohort_report(cohort_name, time_range={}, port=8051):
         questions = list(survey_questions.values())
 
         fig = make_subplots(rows=num_row, cols=num_col, subplot_titles=questions)
-        for i, question in enumerate(questions):
-            fig.add_trace(
-                go.Histogram(
-                    x=survey_report[question],
-                    # xbins=dict(
-                    #     start= 1,
-                    #     end= 10,
-                    #     size=1
-                    # ),
-                    bingroup=1,
-                ),
-                row=(i//num_col) + 1, col=(i % num_col)+1
-            )
-            fig.update_xaxes(title_text=f'Average: {math.ceil(survey_report[question].mean()*100)/100}', row=(i//num_col) + 1, col=(i % num_col)+1)
+        if survey_report.shape[0] > 0:
+            for i, question in enumerate(questions):
+                fig.add_trace(
+                    go.Histogram(
+                        x=survey_report[question],
+                        # xbins=dict(
+                        #     start= 1,
+                        #     end= 10,
+                        #     size=1
+                        # ),
+                        bingroup=1,
+                    ),
+                    row=(i//num_col) + 1, col=(i % num_col)+1
+                )
+                fig.update_xaxes(title_text=f'Average: {math.ceil(survey_report[question].mean()*100)/100}', row=(i//num_col) + 1, col=(i % num_col)+1)
 
         fig.update_xaxes(
             range=[1,11],  # sets the range of xaxis
